=======
stupidb
=======

.. image:: https://img.shields.io/pypi/v/stupidb.svg
        :target: https://pypi.python.org/pypi/stupidb

.. image:: https://img.shields.io/travis/cpcloud/stupidb.svg
        :target: https://travis-ci.org/cpcloud/stupidb

.. image:: https://readthedocs.org/projects/stupidb/badge/?version=latest
        :target: https://stupidb.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Are you tired of software that's too smart? Try StupiDB, the stupidest
database you'll ever come across.

StupiDB was built to understand how a relational database might be implemented.

Systems like PostgreSQL are extremely complex. It's hard for to me to imagine
what implementing the simplest, stupidest core of something like PostgreSQL
would look like, so I decided to write my own.

* Free software: Apache Software License 2.0
* Documentation: https://stupidb.readthedocs.io.

Features
--------
* Stupid joins
* Stupid window functions
* Sophomoric group bys
* Stupidly scales down
* Doesn't work with your microservice
* No documentation
* Not even close to 100% test coverage

Non-Features
------------
* Stupid simple in-memory format
* Stupidly easy to read codebase
* User defined aggregates, including custom stupid window aggregates
* "Volanco" tuple-at-a-time model

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
